==> acornlib-1.21.5-r19-sources.jar: net/acoyt/acornlib/impl/mixin/client/ItemModelManagerMixin.java <==
package net.acoyt.acornlib.impl.mixin.client;

import net.acoyt.acornlib.impl.index.AcornComponents;
import net.minecraft.class_10439;
import net.minecraft.class_10442;
import net.minecraft.class_10444;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_638;
import net.minecraft.class_811;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.Function;

@Mixin(class_10442.class)
public class ItemModelManagerMixin {
    @Shadow @Final private Function<class_2960, class_10439> modelGetter;

    @Inject(
            method = "update",
            at = @At("HEAD")
    )
    private void gnarpian$soShiny(class_10444 renderState, class_1799 stack, class_811 displayContext, class_1937 world, class_1309 entity, int seed, CallbackInfo ci) {
        if (stack != null) {
            if (stack.method_57826(AcornComponents.SECONDARY_MODEL)) {
                this.modelGetter.apply(stack.method_58695(AcornComponents.SECONDARY_MODEL, class_2960.method_60656("carrot")))
                        .method_65584(renderState, stack, (class_10442)(Object)this, displayContext, world instanceof class_638 clientWorld ? clientWorld : null, entity, seed);
            }

            if (stack.method_57826(AcornComponents.TERTIARY_MODEL)) {
                this.modelGetter.apply(stack.method_58695(AcornComponents.TERTIARY_MODEL, class_2960.method_60656("carrot")))
                        .method_65584(renderState, stack, (class_10442)(Object)this, displayContext, world instanceof class_638 clientWorld ? clientWorld : null, entity, seed);
            }
        }
    }
}

==> acornlib-1.21.8-r5-sources.jar: net/acoyt/acornlib/impl/mixin/client/ItemModelManagerMixin.java <==
package net.acoyt.acornlib.impl.mixin.client;

import net.acoyt.acornlib.impl.init.AcornComponents;
import net.minecraft.class_10439;
import net.minecraft.class_10442;
import net.minecraft.class_10444;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2960;
import net.minecraft.class_638;
import net.minecraft.class_811;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.function.Function;

@Mixin(class_10442.class)
public class ItemModelManagerMixin {
    @Shadow @Final private Function<class_2960, class_10439> modelGetter;

    @Inject(
            method = "update",
            at = @At("HEAD")
    )
    private void gnarpian$soShiny(class_10444 renderState, class_1799 stack, class_811 displayContext, class_1937 world, class_1309 entity, int seed, CallbackInfo ci) {
        if (stack != null) {
            if (stack.method_57826(AcornComponents.SECONDARY_MODEL)) {
                this.modelGetter.apply(stack.method_58695(AcornComponents.SECONDARY_MODEL, class_2960.method_60656("carrot")))
                        .method_65584(renderState, stack, (class_10442)(Object)this, displayContext, world instanceof class_638 clientWorld ? clientWorld : null, entity, seed);
            }

            if (stack.method_57826(AcornComponents.TERTIARY_MODEL)) {
                this.modelGetter.apply(stack.method_58695(AcornComponents.TERTIARY_MODEL, class_2960.method_60656("carrot")))
                        .method_65584(renderState, stack, (class_10442)(Object)this, displayContext, world instanceof class_638 clientWorld ? clientWorld : null, entity, seed);
            }
        }
    }
}
